#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Nov  6 14:00:56 2018

@author: nicolai & audiffren
"""

import numpy as np
import argparse
from swarii import SWARII, WBB_splitter
from gmm_classification import GMM_Score_predictor
import warnings
from plots import create_animated_stato, plot_score
from multiprocessing import Process


warnings.filterwarnings("ignore")


if __name__ == "__main__":
    
    # Argument Parsing
    
    args = argparse.ArgumentParser()
    args.add_argument('input', metavar='input', type=str, nargs='+',
                       help='path of the input')
    args.add_argument('block_size', metavar='block_size', type=int, nargs='+',
                       help='time unit')
    
    
    parsed_args = args.parse_args()
    file_address = parsed_args.input[0]
    block_size = parsed_args.block_size[0]
    
    # Reading input
    open_data, close_data = WBB_splitter.parse(file_address)
    
    # Resampling
    open_data = np.array(SWARII.resample(open_data))
    close_data = np.array(SWARII.resample(close_data))
    
    
    # Scoring 
    mygmm = GMM_Score_predictor()
    scores = np.array(mygmm.predict_one([open_data,close_data],window_size=block_size))
    
    score_open = int(100*(1-np.mean(scores[0])))
    score_close =int(100*(1-np.mean(scores[1])))
    
    print(score_open,score_close)
    
    plot_score(score_open,eye="open")
    plot_score(score_close,eye="closed")
    
    
    p1 = Process(target = create_animated_stato,\
                 args =(open_data,scores[0],"open",block_size*25,12))
    p2 = Process(target = create_animated_stato,\
                 args =(close_data,scores[1],"closed",block_size*25,12))
    
    p1.start()
    p2.start()
    p1.join()
    p2.join()
    
    
#    create_animated_stato(data=open_data,scores=scores[0],eye="open",win_duration=block_size*25,overlap=12)
#    print("done first video")
#    create_animated_stato(data=close_data,scores=scores[1],eye="closed",win_duration=block_size*25,overlap=12)   
#
