#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Nov  7 07:10:16 2018

@author: nicolai & audiffren
"""

import matplotlib as mpl
mpl.use('Agg')
import matplotlib.pyplot as plt
import matplotlib.animation as animation
import numpy as np
from math import pi



                
                

plt.ioff()



def plot_score(score,eye):
    max_score=100
    xval = np.arange(0, 2*pi*(.05+0.90*(score/max_score)), 0.01)
    

    colormap = plt.get_cmap("RdYlGn")
    norm = mpl.colors.Normalize(0.0, 2*np.pi)
    
    f, ax = plt.subplots(nrows=1, ncols=1, figsize=(4,4),subplot_kw=dict(projection='polar'))
    
    #Scatter version
    yval = np.ones_like(xval)
    ax.scatter(xval, yval, c=xval, s=300, cmap=colormap, norm=norm, linewidths=0)
    
    #Circle version
    #for i in range(len(xval)-2):
    #    ax.plot( xval[i:i+2], [1.,1.], linewidth = 20, linestyle='solid', color = colormap(norm(xval[i] )))
    
    ax.set_axis_off()
    ax.set_ylim(0,1.5)
    if score<10:
        ax.annotate(score,xy=( 1.25*pi, .3),color=colormap(.05+0.90*(score/max_score)),fontsize=50)
    else :
        ax.annotate(score,xy=( 1.18*pi, .5),color=colormap(.05+0.90*(score/max_score)),fontsize=50)
        
    f.savefig(eye+"_eyes.png")
    f.show()
    


dpi = 100

color_list=['blue','green','red','cyan','magenta','black']

colors=[]
for c in range(101):
    score = 0.01*c        
    if score<0.3 :
        color= (0,(0.3-score)/0.3,score/0.3)
    else :
        color= ((score-0.3)/0.7, 0,(1-score)/0.7)
    colors.append(color)
                
                
                
class TimeCounter :
    def __init__(self,pic,timeline,window_duration,overlap,scores):
        self.time=-1
        self.pic=pic
        self.timeline=timeline
        self.window_duration = window_duration
        self.overlap = overlap
        self.origin=-1
        self.scores=scores
        self.window_number=-1
        
    def new_origin(self,pic,timeline):
        self.origin=self.time
        self.pic=pic
        self.timeline=timeline
        self.window_number = self.get_window_number()
        
        
    def increase(self,value=1):
        self.time+=value
        
    def get_window_number(self):
        n = int( self.time/self.overlap )
        return n
        
    def get_color(self):
        global colors  
        current_score = int(100*self.scores[min(len(self.scores)-1,self.get_window_number())])
        return colors[current_score]
        

def create_animated_stato(data,scores,eye,win_duration,overlap,fast_speed=2):
    
    global colors
    fig = plt.figure()
    
    gs = mpl.gridspec.GridSpec(2, 1, height_ratios=[4, 1]) 
    
    ax = fig.add_subplot(gs[0])
    ax2 = fig.add_subplot(gs[1])
    
    ax.set_aspect('equal')
    
    centered_data = data - np.mean(data,axis=0,keepdims=True)
    ax.set_xlim(-3,3)
    ax.set_ylim(-3,3)
    
    n=len(centered_data)    
    
    ax2.get_xaxis().set_visible(False)
    ax2.get_yaxis().set_visible(False)
    ax2.set_xlim(0,1.*n/ 25)
    ax2.set_ylim(0,1)
    
    
    
    
    x = centered_data[:,0]
    y = centered_data[:,1]
    
    
    col = colors[int(100*scores[0])]

    im, = ax.plot(x[0:0],y[0:0],color=col)
    im2,= ax2.bar(x=[0.],height=[1.],width=0.,color=col)
    timeC=TimeCounter(im,im2,window_duration=win_duration,overlap=overlap,scores=scores)
    fig.set_size_inches([5,5])
    plt.tight_layout()
    
            



    def update_img(frames):
        for i in range(fast_speed):
            timeC.increase()
            time=timeC.time
            win_n = timeC.get_window_number()
            
            im=timeC.pic
            im2 = timeC.timeline
            im.set_data(x[timeC.origin:time+1],y[timeC.origin:time+1])
            im2.set_width((time+1-timeC.origin)/25.)
            if win_n != timeC.window_number :
                im, = ax.plot([],[],color=timeC.get_color())
                im2, = ax2.bar(x=[time/25.],height=[1.],width=0,color=timeC.get_color())
                timeC.new_origin(im,im2)
        
        return im

    ani = animation.FuncAnimation(fig,update_img,frames=range(0,(n-2)//fast_speed),interval=40*fast_speed)
    fps = 1000 / (40*fast_speed)
    writer = animation.FFMpegWriter(fps=int(fps))
    ani.save( eye+"_eyes.mp4",writer=writer)
                
                
                
                
                
                
                
                
                