# -*- coding: utf-8 -*-
"""
Created on Fri Apr 15 10:25:45 2016

@author: audiffren
"""

import numpy as np
    
        
class WBB_splitter_old :
    @staticmethod
    def parse(file_address):
        f=open(file_address,"rt+")
        l=f.readline()
        t_open=[]
        x_open=[]
        y_open=[]
        t_close=[]
        x_close=[]
        y_close=[]
        
        while "Open Eyes\n" not in l:
            l=f.readline()
            if len(l)==0:
                return 

        l=f.readline()            
        while "Closed Eyes" not in l:
            t,x,y= [float(s) for s in l.split(" ")]
            t_open.append(t)
            x_open.append(x)
            y_open.append(y)
            l=f.readline()
            if len(l)==0:
                return 
            

        
        l=f.readline()    
        while len(l)>0:
            l=l[:-1]
            t,x,y= [float(s) for s in l.split(" ")]
            t_close.append(t)
            x_close.append(x)
            y_close.append(y)
            l=f.readline()
            
            
        t_open,x_open,y_open = zip(*sorted(zip(t_open,x_open,y_open)))
        data_open = np.array([t_open,x_open,y_open]).T
        
        t_close,x_close,y_close = zip(*sorted(zip(t_close,x_close,y_close)))
        data_close = np.array([t_close,x_close,y_close]).T    
        
        
        return data_open,data_close
            
class WBB_splitter :
    @staticmethod
    def parse(file_address):
        
        data= np.loadtxt(fname=file_address,skiprows=1)
        data_open = data[data[:,0]==0][:,1:]
        data_close = data[data[:,0]==1][:,1:]
        return data_open,data_close        
        
        
        

class Local_SWARII:
    """
    Implementation of the Sliding Windows Weighted Averaged Interpolation method
    
    How To use :
        First instantiate the class with the desired parameters
        Then call resample on the desired signal
        
    """

    def __init__(self, window_size=1, desired_frequency=25):
        """
        Instantiate SWARII 

        Parameters :
            desired_frequency : The frequency desired for the output signal,
                                after the resampling.
            window_size : The size of the sliding window, in seconds.
        """
        self.desired_frequency = desired_frequency
        self.window_size = window_size


    def resample(self, time, signal):
        """
        Apply the SWARII to resample a given signal.
        
        Input :
            time:   The time stamps of the the data point in the signal. A 1-d
                    array of shape n, where n is the number of points in the
                    signal. The unit is seconds.
            signal: The data points representing the signal. A k-d array of
                    shape (n,k), where n is the number of points in the signal,
                    and k is the dimension of the signal (e.g. 2 for a
                    statokinesigram).
                    
        Output: 
            resampled_time : The time stamps of the signal after the resampling
            resampled_signal : The resampled signal.
        """
        
        a_signal=np.array(signal)
        current_time = max(0.,time[0])
        #print current_time
        output_time=[]
        output_signal = []

        while current_time < time[-1]:

            relevant_times = [t for t in range(len(time)) if abs(
                time[t] - current_time) < self.window_size * 0.5]
            if len(relevant_times) == 0 :
                print("Trying to interpolate an empty window ! at time ", current_time)
                pass
            
            else :
                if len(relevant_times) == 1:
                    value = a_signal[relevant_times[0]]
                    
                else :
                    value = 0
                    weight = 0
            
                    for i, t in enumerate(relevant_times):
                        if i == 0 or t==0:
                            left_border = max(
                                time[0], (current_time - self.window_size * 0.5))
                            
                        else:
                            left_border = 0.5 * (time[t] + time[t - 1])
                            
                            
    
                        if i == len(relevant_times) - 1:
                            right_border = min(
                                time[-1], current_time + self.window_size * 0.5)
                        else:
                            right_border = 0.5 * (time[t + 1] + time[t])
                            
                        w = right_border - left_border
                            
    
                        value += a_signal[t] * w
                        weight += w
            
                            
          
                    value /= weight
                output_time.append(current_time)
                output_signal.append(value)
            current_time += 1. / self.desired_frequency

        return np.array(output_time),np.array(output_signal)


    @staticmethod
    def purge_artefact(time, signal, threshold_up=2, threshold_down=0.5):
        asignal = np.array(signal)
        nsignal=[]
        ntime=[]
        n_artefact=0
        
        for t in range(1,len(time)-1):
            if time[t]<0.1:
                pass
            elif (len(ntime)>0 and t>0 and t<len(time)-1  and np.sum(np.abs(asignal[t+1]-nsignal[-1]))<threshold_down and np.sum(np.abs(asignal[t]-nsignal[-1])) > threshold_up):
                n_artefact+=1
                pass
            elif (len(ntime)>0 and t>1 and t<len(time)-2  and np.sum(np.abs(asignal[t+2]-nsignal[-1]))<threshold_down and np.sum(np.abs(asignal[t]-nsignal[-1])) > threshold_up):
                n_artefact+=1
                pass
            else :
                ntime.append(time[t])
                nsignal.append(signal[t])
        print("skipped", n_artefact, "artefacts"               )
        return ntime,nsignal
            
        


class SWARII :
    @staticmethod
    def resample(data,window_size=80,desired_frequency=0.025):
        swarii = Local_SWARII(window_size=window_size-1e-6,desired_frequency=desired_frequency)
        t = data[:,0]
        signal = data[:,1:]
        nt,nsignal = Local_SWARII.purge_artefact(t,signal)   
        
        #t_close,x_close = swarii.resample(t,x)
        #t_close,y_close = swarii.resample(t,y)
        
        nnt,nnsignal= swarii.resample(nt,nsignal)
        
        return nnsignal
        
        
